% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classificationMatrix.R
\name{ROCplot}
\alias{ROCplot}
\title{Plots a ROC curve from a series of labels and scores returned by a classifier.
In multiclass cases plots a ROC curve for each class applying a one versus all
approach.}
\usage{
ROCplot(real, score, single = TRUE, plot_classes = NULL)
}
\arguments{
\item{real}{a vector with the real class labels associated to observations.}

\item{score}{a vector with the probability values assigned to each observation
by the classifier. The length of this vector has to coincid with that of the real
labels vector.}

\item{single}{an optional boolean. It indicates if a single plot has to be
produced or not. By default a single plot is produced.}

\item{plot_classes}{an optional vector with the different class labels whose
ROC curves have to be displayed. Only those classes included in the \code{real}
vector are taken into account. By default it is set to NULL.}
}
\value{
Returns plots with one ROC curve (binary case) or with a ROC curve per
class (multiclass case) using the the class reference formulation (i.e. one
versus all) approach. Classes are considered in the order specified by
the vector with the \code{real} class labels.
}
\description{
Plots a ROC curve from a series of labels and scores returned by a classifier.
In multiclass cases plots a ROC curve for each class applying a one versus all
approach.
}
\examples{

## Simulates classification results
class_values <- sample(c(TRUE, FALSE), 20, replace = TRUE )
classifier_scores <- runif(20)
ROCplot(class_values, classifier_scores)

## Simulates multiclASS classification results
class_values <- sample( c("a","b","c"), 20, replace = TRUE )
classifier_scores <- runif(20)
# Plot multiclass ROC
# A unique plot
ROCplot(class_values, classifier_scores)
ROCplot(class_values, classifier_scores, plot_classes = c("a", "c"))
# One plot per class
ROCplot(class_values, classifier_scores, FALSE)
ROCplot(class_values, classifier_scores, FALSE, plot_classes = c("a", "c"))

}
\seealso{
\link{classificationMatrix}, \code{pROC}
}
