% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HPDGClassifier.R
\name{crossValidation}
\alias{crossValidation}
\title{Function for performing k-fold cross validation of an Hybrid Probabilistic Decision
Graph (HPDG) classifier on a dataset. The HPDG Classifier is learnt on the whole
data set. The evaluation results displayed are obtained doing the k-fold cross
validation process.}
\usage{
crossValidation(folds = NULL, dataset, method = c("ranked", "rankedCR",
  "CR", "NB", "ChowLiu"), densityType = c("MOP", "MTE"), maxIntervals,
  collapseRate, mergeRate, maxTermsDensity)
}
\arguments{
\item{folds}{the number of folds to be used. It has to be greater than 1. By default is set to 5.}

\item{dataset}{a String indicating the data file (the path has to be included also). Data columns
are separated by ";" and a header indicates the variables names.}

\item{method}{the method applied to build the classifier:
\itemize{
   \item{ranked}{The variables are ranked by mutual information and they are connected as:
                 C -> X_1 -> X_2 -> X_3 -> ...}
   \item{rankedCR}{The variables are ranked by mutual information and then each X_i is
                 connected to the leaf that maximizes the CR of the classifier wrt to a
                 test database.}
   \item{CR}{In each step a non included variable Xj is connected to a leaf variable Xi
                 satisfying that <X_i, X_j> = arg max CR(X_i,X_j,pdg,train,test). This is
                 computationally the hardest option. See Nielsen et. al (2009) - Algorithm 2.}
   \item{NB}{Variables are arranged following a NB structure.}
   \item{ChowLiu}{Variables are arranged in a TAN structure given by the Chow Liu algorithm.}
 }}

\item{densityType}{the type of density ("MOP" or "MTE").}

\item{maxIntervals}{maximum number of intervals in which the continuous parents are split.}

\item{collapseRate}{A number k in the formula nCases = k * R(Xi), where R(Xi) is the number of
states in the variable Xi and nCases is the minimum number of cases to be
allowed to learn the parameters without collapsing nodes. By default this
number is set to 0.5.}

\item{mergeRate}{A number between 0 and 1 indicating the percentage of parameters to be checked
for merging (non mandatory argument). By default this argument is set to 0.5.}

\item{maxTermsDensity}{the maximum number of terms to be fit in the density.}
}
\value{
Return an HPDG classifier learnt using the whole given dataset.
}
\description{
Function for performing k-fold cross validation of an Hybrid Probabilistic Decision
Graph (HPDG) classifier on a dataset. The HPDG Classifier is learnt on the whole
data set. The evaluation results displayed are obtained doing the k-fold cross
validation process.
}
\examples{
 \dontrun{
## Learns a hpdg classifier from a dataset and evaluates its performance applying
## k-fold cross validation
classifier <- crossValidation(2, "data/iris.csv", "rankedCR", "MOP", 3, 2, 0.5, 5)
}

}
\seealso{
\code{\link{hpdgclassifier}}, \code{\link{classificationMatrix}}
}
